==> haskell-equivalence-0.3.2-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.2
id: equivalence-0.3.2-3KXUMF3chYxDgZgaRfCp58
key: equivalence-0.3.2-3KXUMF3chYxDgZgaRfCp58
license: BSD-3-Clause
maintainer: paba@di.ku.dk
author: Patrick Bahr
stability: provisional
homepage: https://github.com/pa-ba/equivalence
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
abi: 20d59e546b872ef0fbd0658b76fc5830
exposed: True
exposed-modules:
    Data.Equivalence.Monad Data.Equivalence.STT
import-dirs: /usr/lib/ghc-8.4.3/site-local/equivalence-0.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/equivalence-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/equivalence-0.3.2
hs-libraries: HSequivalence-0.3.2-3KXUMF3chYxDgZgaRfCp58
depends:
    base-4.11.1.0 containers-0.5.11.0 mtl-2.2.2
    STMonadTrans-0.4.3-EwuLRjXHjqhA7PmvwSfVjr transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             STMonadTrans-0.4.3-EwuLRjXHjqhA7PmvwSfVjr=28f649396f08d40de897e0a867bc6a6f
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-equivalence-0.3.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.3
id: equivalence-0.3.3-7vLwalHGxwR51UxvLXwhWy
key: equivalence-0.3.3-7vLwalHGxwR51UxvLXwhWy
license: BSD-3-Clause
maintainer: paba@itu.dk
author: Patrick Bahr
stability: provisional
homepage: https://github.com/pa-ba/equivalence
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
abi: 96771071b9294e40e8f5cd2b2f4f6c8a
exposed: True
exposed-modules:
    Data.Equivalence.Monad Data.Equivalence.STT
import-dirs: /usr/lib/ghc-8.4.3/site-local/equivalence-0.3.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/equivalence-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/equivalence-0.3.3
hs-libraries: HSequivalence-0.3.3-7vLwalHGxwR51UxvLXwhWy
depends:
    base-4.11.1.0 containers-0.5.11.0 mtl-2.2.2
    STMonadTrans-0.4.3-EwuLRjXHjqhA7PmvwSfVjr transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             STMonadTrans-0.4.3-EwuLRjXHjqhA7PmvwSfVjr=28f649396f08d40de897e0a867bc6a6f
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
